# TODO

[ ] Make title, description, which problem is solve, metter of this project description

[ ] Add more [classifiers](https://pypi.org/classifiers/)

[ ] Add tests

[ ] Add additional links to project conf

[ ] Add poetry scripts and pre-commit scripts

[ ] Add poetry post install, if git exists andd to gitignore and setup pre commit hook, and setup config module, if not exists, create and setup it
